---
name: Support question
about: "If you have a question \U0001F4AC, or something was not clear from the docs!"
title: ""
labels: ""
assignees: ""
---

Please make sure you have read our
[main Readme](https://github.com/jmaupetit/onzr) as well as our
[documentation](https://jmaupetit.github.io/onzr/).

Also make sure it was not already answered in
[an open or close issue](https://github.com/jmaupetit/onzr/issues).

If your question was not covered, and you feel like it should be, fire away!
We'd love to improve our docs! 👌

**Topic** What's the general area of your question: for example, project setup,
installation, interoperability...

**Question** Try to be as specific as possible so we can help you as best we
can. Please be patient 🙏
